@@ -1,7 +1,7 @@
 /*-------------------------------------------------------------------------
  *
  * print.c
- *	  themes initialization
+ *	  visualisation loaded data
  *
  * Portions Copyright (c) 2017-2018 Pavel Stehule
  *
@@ -110,11 +110,8 @@ window_fill(int window_identifier,
 
 				lnb->lineinfo = malloc(1000 * sizeof(LineInfo));
 				if (lnb->lineinfo == NULL)
-				{
-					endwin();
-					fprintf(stderr, "out of memory");
-					exit(1);
-				}
+					leave_ncurses("out of memory");
+
 				memset(lnb->lineinfo, 0, 1000 * sizeof(LineInfo));
 
 				for (i = 0; i < lnb->nrows; i++)
@@ -445,7 +442,7 @@ window_fill(int window_identifier,
 						{
 							if (is_found_row && htrpos >= scrdesc->found_start_x &&
 									htrpos < scrdesc->found_start_x + scrdesc->searchterm_char_size)
-								new_attr = new_attr | A_REVERSE;
+								new_attr = new_attr ^ A_REVERSE;
 							else if (is_pattern_row && htrpos >= lineinfo->start_char)
 							{
 								if ((lineinfo->mask & LINEINFO_FOUNDSTR_MULTI) != 0)
