@@ -44,6 +44,8 @@ if_notin_int(int v, const int *s, int v1, int v2)
 void
 initialize_color_pairs(int theme)
 {
+	init_pair(21, COLOR_WHITE, COLOR_BLACK);		/* Fx keys */
+
 	switch (theme)
 	{
 		case 0:
@@ -67,6 +69,7 @@ initialize_color_pairs(int theme)
 			init_pair(17, -1, -1);							/* color of line art with pattern */
 			init_pair(18, -1, -1);		/* color of marked search pattern in no-hl line mode */
 			init_pair(19, -1, -1);		/* color of marked search pattern in cursor */
+			init_pair(20, COLOR_WHITE, COLOR_BLACK);
 
 			break;
 		case 1:
@@ -76,11 +79,11 @@ initialize_color_pairs(int theme)
 			init_pair(3, COLOR_WHITE, COLOR_BLUE);
 			init_pair(4, COLOR_YELLOW, COLOR_BLUE);
 			init_pair(5, COLOR_YELLOW, COLOR_CYAN);
-			init_pair(6, COLOR_WHITE, COLOR_CYAN);
+			init_pair(6, COLOR_BLACK, COLOR_CYAN);
 			init_pair(7, COLOR_BLACK, COLOR_CYAN);
 			init_pair(8, COLOR_RED, COLOR_BLUE);
 			init_pair(9, COLOR_CYAN, COLOR_BLUE);
-			init_pair(10, COLOR_WHITE, COLOR_CYAN);
+			init_pair(10, COLOR_BLACK, COLOR_CYAN);
 			init_pair(11, COLOR_WHITE, COLOR_CYAN);
 			init_pair(12, COLOR_WHITE, COLOR_CYAN);
 			init_pair(13, COLOR_YELLOW, COLOR_CYAN);
@@ -90,7 +93,7 @@ initialize_color_pairs(int theme)
 			init_pair(17, COLOR_WHITE, COLOR_GREEN);
 			init_pair(18, COLOR_GREEN, COLOR_BLUE);
 			init_pair(19, COLOR_YELLOW, COLOR_CYAN);
-			init_pair(20, COLOR_WHITE, COLOR_CYAN);
+			init_pair(20, COLOR_WHITE, COLOR_BLACK);
 			break;
 		case 2:
 			assume_default_colors(COLOR_WHITE, COLOR_CYAN);
@@ -113,7 +116,7 @@ initialize_color_pairs(int theme)
 			init_pair(17, COLOR_WHITE, COLOR_GREEN);
 			init_pair(18, COLOR_YELLOW, COLOR_GREEN);
 			init_pair(19, COLOR_YELLOW, COLOR_BLUE);
-			init_pair(20, COLOR_YELLOW, COLOR_BLUE);
+			init_pair(20, COLOR_WHITE, COLOR_BLACK);
 
 			break;
 		case 3:
@@ -137,7 +140,7 @@ initialize_color_pairs(int theme)
 			init_pair(17, COLOR_BLACK, COLOR_GREEN);
 			init_pair(18, COLOR_WHITE, COLOR_GREEN);
 			init_pair(19, COLOR_YELLOW, COLOR_BLACK);
-			init_pair(20, COLOR_YELLOW, COLOR_BLACK);
+			init_pair(20, COLOR_WHITE, COLOR_BLUE);
 
 			break;
 		case 4:
@@ -233,7 +236,7 @@ initialize_color_pairs(int theme)
 			init_pair(17, COLOR_GREEN, COLOR_CYAN);
 			init_pair(18, COLOR_CYAN, COLOR_BLACK);
 			init_pair(19, COLOR_CYAN, COLOR_GREEN);
-			init_pair(20, COLOR_CYAN, COLOR_GREEN);
+			init_pair(20, COLOR_WHITE, COLOR_BLACK);
 
 			break;
 		case 8:
@@ -257,7 +260,7 @@ initialize_color_pairs(int theme)
 			init_pair(17, COLOR_CYAN, COLOR_GREEN);
 			init_pair(18, COLOR_CYAN, COLOR_BLUE);
 			init_pair(19, COLOR_YELLOW, COLOR_CYAN);
-			init_pair(20, COLOR_YELLOW, COLOR_CYAN);
+			init_pair(20, COLOR_YELLOW, COLOR_BLACK);
 
 			break;
 		case 9:
@@ -281,7 +284,7 @@ initialize_color_pairs(int theme)
 			init_pair(17, COLOR_WHITE, COLOR_GREEN);
 			init_pair(18, COLOR_YELLOW, COLOR_BLUE);
 			init_pair(19, COLOR_YELLOW, COLOR_CYAN);
-			init_pair(20, COLOR_YELLOW, COLOR_CYAN);
+			init_pair(20, COLOR_YELLOW, COLOR_BLACK);
 
 			break;
 		case 10:
@@ -305,7 +308,7 @@ initialize_color_pairs(int theme)
 			init_pair(17, COLOR_BLUE, COLOR_GREEN);
 			init_pair(18, COLOR_YELLOW, COLOR_CYAN);
 			init_pair(19, COLOR_YELLOW, COLOR_BLUE);
-			init_pair(20, COLOR_YELLOW, COLOR_BLUE);
+			init_pair(20, COLOR_WHITE, COLOR_BLACK);
 
 			break;
 		case 11:
@@ -329,7 +332,7 @@ initialize_color_pairs(int theme)
 			init_pair(17, COLOR_CYAN, COLOR_GREEN);
 			init_pair(18, COLOR_YELLOW, COLOR_BLACK);
 			init_pair(19, COLOR_CYAN, COLOR_MAGENTA);
-			init_pair(20, COLOR_CYAN, COLOR_MAGENTA);
+			init_pair(20, COLOR_WHITE, COLOR_BLUE);
 
 			break;
 		case 12:
@@ -353,18 +356,18 @@ initialize_color_pairs(int theme)
 			init_pair(17, COLOR_BLUE, COLOR_GREEN);
 			init_pair(18, COLOR_YELLOW, COLOR_CYAN);
 			init_pair(19, COLOR_CYAN, COLOR_BLUE);
-			init_pair(20, COLOR_CYAN, COLOR_BLUE);
+			init_pair(20, COLOR_WHITE, COLOR_MAGENTA);
 
 			break;
 		case 13:
 			assume_default_colors(COLOR_WHITE, COLOR_BLUE);
 
-			init_pair(2, COLOR_WHITE, COLOR_BLUE);
+			init_pair(2, COLOR_WHITE, COLOR_BLACK);
 			init_pair(3, COLOR_WHITE, COLOR_BLUE);
 			init_pair(4, COLOR_WHITE, COLOR_BLUE);
-			init_pair(5, COLOR_BLACK, COLOR_CYAN);
-			init_pair(6, COLOR_BLACK, COLOR_CYAN);
-			init_pair(7, COLOR_WHITE, COLOR_BLUE);
+			init_pair(5, COLOR_YELLOW, COLOR_CYAN);
+			init_pair(6, COLOR_YELLOW, COLOR_CYAN);
+			init_pair(7, COLOR_WHITE, COLOR_BLACK);
 			init_pair(8, COLOR_WHITE, COLOR_BLUE);
 			init_pair(9, COLOR_WHITE, COLOR_BLUE);
 			init_pair(10, COLOR_BLACK, COLOR_CYAN);
@@ -377,7 +380,7 @@ initialize_color_pairs(int theme)
 			init_pair(17, COLOR_WHITE, COLOR_GREEN);
 			init_pair(18, COLOR_CYAN, COLOR_BLUE);
 			init_pair(19, COLOR_WHITE, COLOR_CYAN);
-			init_pair(20, COLOR_WHITE, COLOR_CYAN);
+			init_pair(20, COLOR_WHITE, COLOR_BLACK);
 
 			break;
 		case 14:
@@ -401,15 +404,68 @@ initialize_color_pairs(int theme)
 			init_pair(17, COLOR_WHITE, COLOR_GREEN);
 			init_pair(18, COLOR_CYAN, COLOR_BLUE);
 			init_pair(19, COLOR_WHITE, COLOR_CYAN);
-			init_pair(20, COLOR_WHITE, COLOR_CYAN);
+			init_pair(20, COLOR_WHITE, COLOR_BLACK);
+			break;
+
+		case 15:
+			assume_default_colors(COLOR_BLACK, COLOR_WHITE);
+
+			init_pair(2, COLOR_BLACK, COLOR_WHITE);
+			init_pair(3, COLOR_BLACK, COLOR_WHITE);
+			init_pair(4, COLOR_RED, COLOR_WHITE);
+			init_pair(5, COLOR_WHITE, COLOR_RED);
+			init_pair(6, COLOR_WHITE, COLOR_RED);
+			init_pair(7, COLOR_BLACK, COLOR_WHITE);
+			init_pair(8, COLOR_WHITE, COLOR_BLUE);
+			init_pair(9, COLOR_BLACK, COLOR_WHITE);
+			init_pair(10, COLOR_WHITE, COLOR_RED);
+			init_pair(11, COLOR_BLACK, COLOR_RED);
+			init_pair(12, COLOR_WHITE, COLOR_BLACK);
+			init_pair(13, COLOR_WHITE, COLOR_BLACK);
+			init_pair(14, COLOR_YELLOW, COLOR_RED);
+			init_pair(15, COLOR_YELLOW, COLOR_BLACK);
+			init_pair(16, COLOR_WHITE, COLOR_BLACK);
+			init_pair(17, COLOR_WHITE, COLOR_BLACK);
+			init_pair(18, COLOR_CYAN, COLOR_BLUE);
+			init_pair(19, COLOR_WHITE, COLOR_CYAN);
+			init_pair(20, COLOR_WHITE, COLOR_BLACK);
+			break;
+
+		case 16:
+			use_default_colors();
+
+			init_pair(2, -1, -1);
+			init_pair(3, -1, -1);
+			init_pair(4, -1, -1);
+			init_pair(5, -1, -1);
+			init_pair(6, -1, -1);
+			init_pair(7, -1, -1);
+			init_pair(8, -1, -1);
+			init_pair(9, -1, -1);
+			init_pair(10, -1, -1);
+			init_pair(11, -1, -1);
+			init_pair(12, -1, -1);
+			init_pair(13, -1, -1);
+			init_pair(14, -1, -1);
+			init_pair(15, -1, -1);
+			init_pair(16, -1, -1);
+			init_pair(17, -1, -1);
+			init_pair(18, -1, -1);
+			init_pair(19, -1, -1);
+			init_pair(20, -1, -1);
+			break;
 
-		break;
 	}
+
 }
 
 #define _in			if_in_int
 #define _notin		if_notin_int
 
+#ifndef A_ITALIC
+#define A_ITALIC	A_DIM
+#endif
+
 void
 initialize_theme(int theme, int window_identifier, bool is_tabular_fmt, bool no_highlight_lines, Theme *t)
 {
@@ -420,7 +476,9 @@ initialize_theme(int theme, int window_identifier, bool is_tabular_fmt, bool no_
 		case WINDOW_LUC:
 		case WINDOW_FIX_ROWS:
 			t->data_attr = COLOR_PAIR(4);
-			t->data_attr |= _notin(theme, (int[]) {12, -1}, A_BOLD, 0);
+			t->data_attr |= _notin(theme, (int[]) {12, 15, -1}, A_BOLD, 0);
+			t->data_attr |= _in(theme, (int[]) {15, -1}, A_DIM, 0);
+			t->data_attr |= _in(theme, (int[]) {16, -1}, A_ITALIC, 0);
 			break;
 
 		case WINDOW_TOP_BAR:
@@ -453,19 +511,26 @@ initialize_theme(int theme, int window_identifier, bool is_tabular_fmt, bool no_
 			t->pattern_data_attr = COLOR_PAIR(16);
 			t->pattern_line_attr = COLOR_PAIR(17);
 
-			t->data_attr |= _notin(theme, (int[]) { 12, -1}, A_BOLD, 0);
+			t->data_attr |= _notin(theme, (int[]) { 12, 15, -1}, A_BOLD, 0);
+			t->data_attr |= _in(theme, (int[]) {15, -1}, A_DIM, 0);
 			t->line_attr |= 0;
 			t->expi_attr |= A_BOLD;
-			t->cursor_data_attr |= _notin(theme, (int[]) { 13, 14, -1}, A_BOLD, 0);
+			t->cursor_data_attr |= _notin(theme, (int[]) {14, -1}, A_BOLD, 0);
 			t->cursor_line_attr |= 0;
 			t->cursor_expi_attr |= A_BOLD;
 			t->cursor_pattern_attr |= A_BOLD;
-			t->bookmark_data_attr |= A_BOLD;
-			t->bookmark_line_attr |= 0;
-			t->cursor_bookmark_attr |= A_REVERSE | A_BOLD;
-			t->found_str_attr |= no_highlight_lines ? (_in(theme, (int[]){0, -1}, A_REVERSE, A_BOLD)) : A_BOLD;
-			t->pattern_data_attr |= _in(theme, (int[]) {0, -1}, A_REVERSE, 0);
-			t->pattern_line_attr |= _in(theme, (int[]) {11, 7, 8, -1}, A_BOLD, 0) | _in(theme, (int[]) {0, -1}, A_REVERSE, 0);
+			t->bookmark_data_attr |= _in(theme, (int[]){15, -1}, A_REVERSE | A_BOLD, A_BOLD);
+			t->bookmark_line_attr |= _in(theme, (int[]){15, -1}, A_REVERSE | A_BOLD, 0);
+			t->cursor_bookmark_attr |= _in(theme, (int[]){15, -1}, A_BOLD, A_REVERSE | A_BOLD);
+			t->found_str_attr |= no_highlight_lines ? (_in(theme, (int[]){0, -1}, A_REVERSE, A_BOLD)) : _in(theme, (int[]){0, 15,  -1}, A_REVERSE | A_BOLD, A_BOLD);
+			t->pattern_data_attr |= _in(theme, (int[]) {15, -1}, A_BOLD, 0) | _in(theme, (int[]) {0, 15, -1}, A_REVERSE, 0);
+			t->pattern_line_attr |= _in(theme, (int[]) {11, 7, 8, 15, -1}, A_BOLD, 0) | _in(theme, (int[]) {0, 15, -1}, A_REVERSE, 0);
+
+			t->cursor_data_attr |= _in(theme, (int[]) {16, -1}, A_REVERSE, 0);
+			t->cursor_line_attr |= _in(theme, (int[]) {16, -1}, A_REVERSE, 0);
+			t->data_attr |= _in(theme, (int[]) {16, -1}, A_ITALIC, 0);
+			t->bookmark_data_attr |= _in(theme, (int[]) {16, -1}, A_UNDERLINE, 0);
+			t->bookmark_line_attr |= _in(theme, (int[]) {16, -1}, A_UNDERLINE, 0);
 			break;
 
 		case WINDOW_ROWS:
@@ -486,16 +551,21 @@ initialize_theme(int theme, int window_identifier, bool is_tabular_fmt, bool no_
 			t->data_attr |= _in(theme, (int[]) { 2, 12, 13, 14, -1}, A_BOLD, 0);
 			t->line_attr |= !is_tabular_fmt ? (_in(theme, (int[]) { 2, -1}, A_BOLD, 0)) : 0;
 			t->expi_attr |= A_BOLD;
-			t->cursor_data_attr |= _notin(theme, (int[]) { 13, 14, -1}, A_BOLD, 0);
+			t->cursor_data_attr |= _notin(theme, (int[]) {14, 1, -1}, A_BOLD, 0);
 			t->cursor_line_attr |= !is_tabular_fmt ? A_BOLD : 0;
 			t->cursor_expi_attr |= A_BOLD;
 			t->cursor_pattern_attr |= A_BOLD;
-			t->bookmark_data_attr |= A_BOLD;
-			t->bookmark_line_attr |= 0;
-			t->cursor_bookmark_attr |= A_REVERSE | A_BOLD;
-			t->found_str_attr |= no_highlight_lines ? (_in(theme, (int[]){0, -1}, A_REVERSE, A_BOLD)) : A_BOLD;
-			t->pattern_data_attr |= _in(theme, (int[]) {0, -1}, A_REVERSE, 0);
-			t->pattern_line_attr |= _in(theme, (int[]) {11, 7, 8, -1}, A_BOLD, 0) | _in(theme, (int[]) {0, -1}, A_REVERSE, 0);
+			t->bookmark_data_attr |= _in(theme, (int[]){15, -1}, A_REVERSE | A_BOLD, A_BOLD);
+			t->bookmark_line_attr |= _in(theme, (int[]){15, -1}, A_REVERSE | A_BOLD, 0);
+			t->cursor_bookmark_attr |= _in(theme, (int[]){15, -1}, A_BOLD, A_REVERSE | A_BOLD);
+			t->found_str_attr |= no_highlight_lines ? (_in(theme, (int[]){0, -1}, A_REVERSE, A_BOLD)) : _in(theme, (int[]){0, 15,  -1}, A_REVERSE | A_BOLD, A_BOLD);
+			t->pattern_data_attr |= _in(theme, (int[]) {15, -1}, A_BOLD, 0) | _in(theme, (int[]) {0, 15, -1}, A_REVERSE, 0);
+			t->pattern_line_attr |= _in(theme, (int[]) {11, 7, 8, 15, -1}, A_BOLD, 0) | _in(theme, (int[]) {0, 15, -1}, A_REVERSE, 0);
+
+			t->cursor_data_attr |= _in(theme, (int[]) {16, -1}, A_REVERSE, 0);
+			t->cursor_line_attr |= _in(theme, (int[]) {16, -1}, A_REVERSE, 0);
+			t->bookmark_data_attr |= _in(theme, (int[]) {16, -1}, A_UNDERLINE, 0);
+			t->bookmark_line_attr |= _in(theme, (int[]) {16, -1}, A_UNDERLINE, 0);
 			break;
 
 		case WINDOW_FOOTER:
@@ -516,7 +586,7 @@ initialize_theme(int theme, int window_identifier, bool is_tabular_fmt, bool no_
 			t->data_attr |= !is_tabular_fmt ? (_in(theme, (int[]) { 2, 12, 13, 14, -1}, A_BOLD, 0)) : 0;
 			t->line_attr |= 0,
 			t->expi_attr |= 0;
-			t->cursor_data_attr |= _notin(theme, (int[]) { 13, 14, -1}, A_BOLD, 0);
+			t->cursor_data_attr |= _notin(theme, (int[]) { 13, 14, 1, -1}, A_BOLD, 0);
 			t->cursor_line_attr |= 0;
 			t->cursor_expi_attr |= 0;
 			t->cursor_pattern_attr |= A_BOLD;
@@ -526,6 +596,7 @@ initialize_theme(int theme, int window_identifier, bool is_tabular_fmt, bool no_
 			t->found_str_attr |= no_highlight_lines ? (_in(theme, (int[]){0, -1}, A_REVERSE, A_BOLD)) : A_BOLD;
 			t->pattern_data_attr |= 0;
 			t->pattern_line_attr |= 0;
+			t->cursor_pattern_attr |= A_REVERSE;
 			break;
 	}
 
