@@ -45,7 +45,7 @@ typedef struct
 #define		WINDOW_TOP_BAR			5
 #define		WINDOW_BOTTOM_BAR		6
 
-void initialize_color_pairs(int theme);
-void initialize_theme(int theme, int window_identifier, bool is_tabular_fmt, bool no_highlight_lines, Theme *t);
+extern void initialize_color_pairs(int theme);
+extern void initialize_theme(int theme, int window_identifier, bool is_tabular_fmt, bool no_highlight_lines, Theme *t);
 
 #endif
\ No newline at end of file
